# autodmri

Automated characterization of noise distributions in diffusion MRI data

You can find the preprint of the manuscript here https://www.biorxiv.org/content/10.1101/686436v1
and the datasets are available here https://zenodo.org/record/2483105

The documentation is also available at http://autodmri.rtfd.io/

I am currently making the code nicer and easily usable (and am busy with other stuff), but the main script is already present with some data.
I should add shortly after an example.
